@@ -22,6 +22,7 @@ sub docroot :lvalue { $_[0]->{docroot} }                 # Path for static docum
 sub conn :lvalue { $_[0]->{conn} }                       # Low-level connection
 sub http_request :lvalue { $_[0]->{http_request} }       # Actual request object
 sub no_content_type :lvalue { $_[0]->{no_content_type} } # Flag, never send type
+sub debug_level :lvalue { $_[0]->{debug_level} }
 
 
 =head1 NAME
@@ -102,11 +103,12 @@ This method is required for all adaptors.
 sub get_request {
   my ($self) = @_;
 
-  # STDERR->print(__FILE__, ' ', __LINE__, "\n");
+  # $self->debug(2,__FILE__, ' ', __LINE__, "\n");
   while(1) {
     my $c = $self->daemon->accept or next;
     my $r = $c->get_request or next;
     return Continuity::Adapt::HttpDaemon::Request->new(
+      debug_level => $self->debug_level,
       conn => $c,
       http_request => $r,
       no_content_type => $self->no_content_type,
@@ -134,7 +136,7 @@ sub map_path {
 
   # if($path =~ m%^/?\.\.(?=/|$)%) then bad
 
-STDERR->print("path: $docroot$path\n");
+$self->debug(2,"path: $docroot$path\n");
 
   return "$docroot$path";
 }
@@ -176,7 +178,7 @@ sub send_static {
 sub debug {
   my ($self, $level, $msg) = @_;
   if(defined $self->debug_level and $level >= $self->debug_level) {
-    STDERR->print("$msg\n"); 
+    $self->debug(2,"$msg\n"); 
   } 
 } 
 
@@ -189,6 +191,14 @@ sub http_request :lvalue { $_[0]->{http_request} } # The HTTP::Request object
 sub write_event :lvalue { $_[0]->{write_event} }   # Watch for writes to the conn
 sub no_content_type :lvalue { $_[0]->{no_content_type} } # Flag, never send type
 sub cached_params :lvalue { $_[0]->{cached_params} }     # CGI query params
+sub debug_level :lvalue { $_[0]->{debug_level} }
+
+sub debug {
+  my ($self, $level, $msg) = @_;
+  if(defined $self->debug_level and $level >= $self->debug_level) {
+    $self->debug(2,"$msg\n"); 
+  } 
+} 
 
 =for comment
 
@@ -221,9 +231,9 @@ sub new {
     my $self = bless { @_ }, $class;
     eval { $self->conn->isa('HTTP::Daemon::ClientConn') } or warn "\$self->conn isn't an HTTP::Daemon::ClientConn";
     eval { $self->http_request->isa('HTTP::Request') } or warn "\$self->http_request isn't an HTTP::Request";
-    STDERR->print( "\n====== Got new request ======\n"
+    $self->debug(2, "\n====== Got new request ======\n"
                . "       Conn: ".$self->conn."\n"
-               . "    Request: $self\n"
+               . "    Request: $self"
     );
     return $self;
 }
@@ -263,7 +273,7 @@ sub param {
 sub params {
     my $self = shift;
     $self->param;
-    return @{$self->{params}};
+    return @{$self->cached_params};
 }
 
 sub end_request {
@@ -279,6 +289,17 @@ sub set_cookie {
     $self->cookies .= "Set-Cookie: $cookie\r\n";
 }
 
+sub get_cookie {
+    my $self = shift;
+    my $cookie_name = shift;
+    my ($cookie) =  map $_->[1],
+      grep $_->[0] eq $cookie_name,
+      map [ m/(.*?)=(.*)/ ],
+      split /; */,
+      $self->headers->header('Cookie') || '';
+    return $cookie;
+}
+
 sub send_basic_header {
     my $self = shift;
     my $cookies = $self->cookies;
@@ -420,7 +441,7 @@ L<Continuity>
 
 =head1 COPYRIGHT
 
-  Copyright (c) 2004-2007 Brock Wilcox <awwaiid@thelackthereof.org>. All rights
+  Copyright (c) 2004-2008 Brock Wilcox <awwaiid@thelackthereof.org>. All rights
   reserved.  This program is free software; you can redistribute it and/or
   modify it under the same terms as Perl itself.
 
